/**
 ** A Virtual Host Monitor
 **
 ** Copyright 2009 Gary Wuertz gary@issiweb.com
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef TOPVHOST_H
#define TOPVHOST_H
/**
 * Application options
 */
struct appOptions {
  char*  configFile;      // configuration file
  char*  configSection;   // config file section
  bool   init;            // read logs at startup
  bool   verify;          // verify settings
};
/**
 * The application
 */
class topvhost {
public:
  enum {                      // display sort order
    BY_ACCESS,
    BY_HITS,
    BY_NAME
  };
  std::string               tline;            // the terminal line
  std::string               hfmt;             // header format
  std::string               rfmt;             // row format
  std::string               logfmt;           // log format
  std::vector<std::string>  needs;            // fields needed for output
  std::vector<std::string>  gets;             // fields provided by log record
  std::map<int,int>         xfer;             // map 'gets' to 'needs'
  bool                      paint;            // forced repaint
  bool                      resize;           // resize the window
  bool                      debug;            // for diganostics
  int                       order;            // current display order
  int                       exit;             // exit code
  int                       maxx;             // number of screen columns
  int                       maxy;             // number of screen rows
  int                       namelen;          // length of longest domain name
  int                       total;            // total hosts
  int                       passes;           // number of execution loops
  time_t                    start;            // time the application started
  void                      *window;          // hide ncurses from rest of app

  void                      begin(appOptions options);        // start the application
  void                      diagMap(unsigned n);              // diagnositcs for field map
  void                      end(void);                        // stop the application
  int                       input(void);                      // get app input
  bool                      isfmt(int c,bool first);          // check format spec
  void                      wmove(int y, int x);              // move cursor
  void                      wprint(std::string fmt,float v);  // print arg
  void                      wprint(std::string fmt,int v);    // print arg
  void                      wprint(std::string fmt,long v);   // print arg
  void                      wput(int ch);                     // add character
  void                      wputs(const char *);              // add string
  int                       wx(void);                         // get x position
  int                       wy(void);                         // get y position
  void                      wyx(void);                        // get screen size
};
#endif
